# pypoint

![GitHub repo size](https://img.shields.io/github/repo-size/almemanuel/pypoint?style=for-the-badge)
![GitHub language count](https://img.shields.io/github/languages/count/almemanuel/pypoint?style=for-the-badge)
![GitHub forks](https://img.shields.io/github/forks/almemanuel/pypoint?style=for-the-badge)
![Bitbucket open issues](https://img.shields.io/bitbucket/issues/almemanuel/pypoint?style=for-the-badge)
![Bitbucket open pull requests](https://img.shields.io/bitbucket/pr-raw/almemanuel/pypoint?style=for-the-badge)


> Solution to integrate SharePoint with your Python script

### Improvement

This project is under development, so if you have any suggestions, please let me know:

- [x] Get file content
- [ ] Search for a file
- [ ] Upload file
- [ ] Edit file

## 💻 Requeriments
Before you begin, ensure you have met the following requirements:
- you have installed a `python 3.8` or higher

## 🚀 Install pypoint
- run the command: `pip install pypoint` to activate the virtual environment
- voilà!

## ☕ Run
To run pypoint, you need a sharepoint account. You can instanciate an object with the following parameters:

```python

pass

```
Actually, is possible download a file from sharepoint:

```python
```

## 📫 Contributing

To contribute to pypoint, follow these steps:
1. Fork this repository.
2. Create a branch: `git checkout -b <branch_name>`.
3. Make your changes and confirm them: `git commit -m '<commit_message>'`
4. Send to the original branch: `git push origin <project_name> <location>`
5. Create the pull request.

Alternatively, consult the GitHub documentation on [creating a pull request](https://help.github.com/en/github/collaborating-with-issues-and-pull-requests/creating-a-pull-request).

## 🤝 Colaborators

<table>
  <tr>
    <td align="center">
      <a href="https://github.com/almemanuel" title="Emanuel's GitHub">
        <img src="https://avatars.githubusercontent.com/u/40006289?v=4" width="100px;" alt="Emanuel's profile photo"/><br>
        <sub>
          <b>Emanuel Almeida</b>
        </sub>
      </a>
    </td>
  </tr>
</table>

## 📝 Licença

This project is under license. See the file [LICENÇA](LICENSE.md) for more details.

[⬆ Turn to top](#pypoint)
<br>
